pub enum CourseCodeVerdict {
Allowed,
NotAllowed {
reason: String,
},
}Expand description
What Suotar’s course-codes/validate said about a course code.
Variants
Implementations
Sourceimpl CourseCodeVerdict
impl CourseCodeVerdict
Sourcepub fn stored(facts: &SuotarModuleConfigFacts) -> Option<Self>
pub fn stored(facts: &SuotarModuleConfigFacts) -> Option<Self>
The verdict the last check stored for the module’s current course code, for rechecking without asking Suotar again.